==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway.md <==
# AwsStorageGatewayFileGateway


```text
aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway
```

```text
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')
```



| Illustration | AwsStorageGatewayFileGateway | AwsStorageGatewayFileGatewayCard | AwsStorageGatewayFileGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway.png) | ![illustration for AwsStorageGatewayFileGateway](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway.Local.png) | ![illustration for AwsStorageGatewayFileGatewayCard](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGatewayCard.Local.png) | ![illustration for AwsStorageGatewayFileGatewayGroup](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGatewayGroup.Local.png) |




## AwsStorageGatewayFileGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGateway('AwsStorageGatewayFileGateway', 'Aws Storage Gateway File Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGateway('AwsStorageGatewayFileGateway', 'Aws Storage Gateway File Gateway', 'an optional tech label')
@enduml
```

## AwsStorageGatewayFileGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayCard('AwsStorageGatewayFileGatewayCard', 'Aws Storage Gateway File Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayCard('AwsStorageGatewayFileGatewayCard', 'Aws Storage Gateway File Gateway Card', 'an optional description')
@enduml
```

## AwsStorageGatewayFileGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayGroup('AwsStorageGatewayFileGatewayGroup', 'Aws Storage Gateway File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayGroup('AwsStorageGatewayFileGatewayGroup', 'Aws Storage Gateway File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway.md <==
# AwsStorageGatewayFileGateway


```text
aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway
```

```text
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')
```



| Illustration | AwsStorageGatewayFileGateway | AwsStorageGatewayFileGatewayCard | AwsStorageGatewayFileGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway.png) | ![illustration for AwsStorageGatewayFileGateway](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway.Local.png) | ![illustration for AwsStorageGatewayFileGatewayCard](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGatewayCard.Local.png) | ![illustration for AwsStorageGatewayFileGatewayGroup](../../../aws-20210730/Resource/Storage/AwsStorageGatewayFileGatewayGroup.Local.png) |




## AwsStorageGatewayFileGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGateway('AwsStorageGatewayFileGateway', 'Aws Storage Gateway File Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGateway('AwsStorageGatewayFileGateway', 'Aws Storage Gateway File Gateway', 'an optional tech label')
@enduml
```

## AwsStorageGatewayFileGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayCard('AwsStorageGatewayFileGatewayCard', 'Aws Storage Gateway File Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayCard('AwsStorageGatewayFileGatewayCard', 'Aws Storage Gateway File Gateway Card', 'an optional description')
@enduml
```

## AwsStorageGatewayFileGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayGroup('AwsStorageGatewayFileGatewayGroup', 'Aws Storage Gateway File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayFileGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayFileGateway')

' renders the element
AwsStorageGatewayFileGatewayGroup('AwsStorageGatewayFileGatewayGroup', 'Aws Storage Gateway File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
